#!/usr/bin/env python

import wx, os
from deditorstc import DemoCodeEditor

class Tab():
    def __init__(self, name, path = None, panel = None, isFile = False):
        self.panel = panel
        self.path = path
        self.name = name
        self.isFile = isFile
        self.editor = None

class TabHolder():
    def __init__(self, notebook):
        self.tabs = []
        self.notebook = notebook
    
    def add_tab(self, name, path=None):
        panel = wx.Panel(self.notebook, -1)
        sizer = wx.BoxSizer(wx.VERTICAL)
        editor = DemoCodeEditor(panel)
        editor.IndicatorSetStyle(2, wx.stc.STC_INDIC_SQUIGGLE)
        editor.IndicatorSetForeground(2, wx.RED)
        editor.StartStyling(1, wx.stc.STC_INDICS_MASK)
        editor.SetStyling(10, wx.stc.STC_INDIC2_MASK)
        sizer.Add(editor, -1, wx.EXPAND)
        panel.SetSizer(sizer)
        tab = Tab(name, path, panel, True)
        tab.editor = editor
        self.tabs.append(tab)
        self.notebook.AddPage(panel, name)
        self.notebook.SetSelection(self.notebook.GetPageCount() - 1)
    
    def close_tab(self):
        page = self.notebook.GetSelection()
        tab = self.tabs[page]
        self.tabs.remove(tab)
        self.notebook.RemovePage(page)
        if len(self.tabs) == 0:
            self.new_file()
    
    def save(self):
        tab = self.get_active_tab()
        if tab.isFile and tab.name != "!New":
            #try:
            txt = tab.editor.GetText()
            if not os.path.isdir(os.path.split(tab.path)[0]):   os.mkdir(os.path.split(tab.path)[0])
            f = open(tab.path, 'w')
            f.write(txt)
            f.close()
            self.notebook.SetPageText(self.notebook.GetSelection(), tab.name)
            #except:
            #    self.SetStatusText("Deditor was not able to save your file..")
        elif tab.isFile and tab.name == "!New":
            self.saveas()
    
    def get_tab(self, page):
        return self.tabs[page]
    
    def get_active_tab(self):
        page = self.notebook.GetSelection()
        return self.tabs[page]
    
    def refresh_file(self):
        """Refreshes the file using the code already in the editor"""
        tab = self.get_active_tab()
        if tab.isFile:
            text = tab.editor.GetText()
            tab.editor.SetText(text)
    
    def new_file(self):
        """Create a new empty tab"""
        self.add_tab("!New")
    
    def lexer(self, lang):
        if lang != None:
            self.get_active_tab().editor.SetLex(lang)
        self.refresh_file()

    def open_file(self, file):
        f = open(file, 'r')
        txt = ""
        for line in f.readlines():
            txt += line
        f.close()
        self.add_tab(os.path.basename(file), file)
        #Set Page to new Tab
        self.notebook.SetSelection(self.notebook.GetPageCount()-1)
        page = self.notebook.GetSelection()
        tab = self.get_tab(page)
        tab.editor.SetValue(txt)
        self.notebook.SetSelection(page)