#!/usr/bin/env python
from __future__ import with_statement
import wx, os
from dialogs import CSDialog, IODialog
from Network import ssh, sftp

def init_dplug(dplug):
    dplug.plugins.network = Network(dplug)
    dplug.add_to("save","network")
    dplug.add_to("configsave","network")
    dplug.add_to("configinit","network")
    dplug.add_cmd("ssh", "network")

def trigger(trig, dplug):
    if trig == "configsave":
        dplug.plugins.network.config.Update()
    elif trig == "configinit":
        dplug.plugins.network.config.Init()
    elif trig == "save":
        dplug.plugins.network.ssh.Save()
        dplug.plugins.network.sftp.Save()

def command(cmd, next, dplug):
    if cmd == "ssh":
        dplug.plugins.network.ssh.Command("ssh", next)

class Network():
    def __init__(self, dplug):
        self.dplug = dplug
        self.gui = dplug.main_class
        self.ssh = ssh.SSH(dplug)
        self.sftp = sftp.SFTP(dplug)
        
        #MENU
        sshmenu = wx.Menu()
        ssh_down_id = wx.NewId()
        ssh_up_id = wx.NewId()
        ssh_shell = wx.NewId()
        ssh_session = wx.NewId()
        sshmenu.Append(ssh_session, "Show SSH Session")
        #self.ssh_upload = sshmenu.AppendCheckItem(ssh_up_id, "Upload")
        #self.ssh_download = sshmenu.AppendCheckItem(ssh_down_id, "Download")
        #sshmenu.Append(ssh_shell,"Open SSH Shell")
        sftpmenu = wx.Menu()
        sftp_down_id = wx.NewId()
        sftp_up_id = wx.NewId()
        sftp_shell = wx.NewId()
        sftp_session = wx.NewId()
        sftpmenu.Append(sftp_session, "Show SFTP Session")
        #self.sftp_upload = sftpmenu.AppendCheckItem(sftp_up_id, "Upload")
        #self.sftp_download = sftpmenu.AppendCheckItem(sftp_down_id, "Download")
        #sftpmenu.Append(sftp_shell,"Open SFTP Shell")
        
        tmpmenu = wx.Menu()
        ssh_status_id = wx.NewId()
        self.ssh_status = tmpmenu.AppendCheckItem(ssh_status_id, "&SSH Enabled")
        sftp_status_id = wx.NewId()
        self.sftp_status = tmpmenu.AppendCheckItem(sftp_status_id, "&SFTP Enabled")
        self.sshmenu = tmpmenu.AppendMenu(-1, '&SSH', sshmenu)
        self.sshmenu.Enable(False)
        self.sftpmenu = tmpmenu.AppendMenu(-1, '&SFTP', sftpmenu)
        self.sftpmenu.Enable(False)
        #tmpmenu.AppendMenu(-1, '&SFTP', sftp.Menu())
        self.gui.menu.Append(tmpmenu, "Network")
        
        self.gui.Bind(wx.EVT_MENU, lambda event: self.ssh.ssh_switch(), id=ssh_status_id)
        self.gui.Bind(wx.EVT_MENU, lambda event: self.ssh.ssh_session(), id=ssh_session)
        self.gui.Bind(wx.EVT_MENU, lambda event: self.ssh.download(), id=ssh_down_id)
        self.gui.Bind(wx.EVT_MENU, lambda event: self.ssh.upload(), id=ssh_up_id)
        self.gui.Bind(wx.EVT_MENU, lambda event: self.ssh.ssh_shell(), id=ssh_shell)
        self.gui.Bind(wx.EVT_MENU, lambda event: self.sftp.sftp_switch(), id=sftp_status_id)
        self.gui.Bind(wx.EVT_MENU, lambda event: self.sftp.download(), id=sftp_down_id)
        self.gui.Bind(wx.EVT_MENU, lambda event: self.sftp.upload(), id=sftp_up_id)
        self.gui.Bind(wx.EVT_MENU, lambda event: self.sftp.sftp_session(), id=sftp_session)
        self.gui.Bind(wx.EVT_MENU, lambda event: self.sftp.sftp_shell(), id=sftp_shell)
        
        self.config = Config(self.gui.confpan, -1, i = self.dplug)

class Config(wx.Panel):
    def __init__(self, parent, sth, i):
        self.dplug = i
        wx.Panel.__init__(self, parent, sth)
        self.siz = wx.BoxSizer(wx.VERTICAL)
        self.networkbook = wx.Notebook(self, -1, style = wx.NB_LEFT)
        self.sshconfig = ssh.Config(self.networkbook, -1, i = self.dplug)
        self.sftpconfig = sftp.Config(self.networkbook, -1, i = self.dplug)
        #All together
        self.networkbook.AddPage(self.sshconfig, "SSH")
        self.networkbook.AddPage(self.sftpconfig, "SFTP")
        self.siz.Add(self.networkbook, -1, wx.EXPAND)
        self.SetSizer(self.siz)
        self.button_name = "Network"
        parent.plugin_add(self)
        
    def Init(self):
        self.sshconfig.Init()
        self.sftpconfig.Init()

    def Update(self):
        self.sshconfig.Update()
        self.sftpconfig.Update()
